@@ -1,4 +1,5 @@
-
+import socket
+import json
 import sys
 import pkg_resources
 import tornado.ioloop
@@ -19,9 +20,10 @@ except ImportError:
 
 import __main__
 
-__version__ = '0.1.4'
+__version__ = '0.1.7'
 
 DEFAULT_PATH='./'
+DEFAULT_HOST=socket.gethostname()
 localpath=str(Path().resolve())
 FRAMEWORK_RUN_FLAG=True
 apps=[]
@@ -29,6 +31,15 @@ apps=[]
 xgeedir = pkg_resources.resource_filename(__name__, "core")
 xgeelayoutmeta = pkg_resources.resource_filename(__name__, "meta/layout.ecore")
 
+
+class XGEEConfigHandler(tornado.web.RequestHandler):
+    ''' Returns the XGEE configuration as JSON '''
+    def initialize(self, xgee_app):
+        self.xgee_app=xgee_app
+    def get(self):
+        xgeeapp_conf='/* Generated XGEE app configuration by XGEE launcher */\n var $XGEE='+str(json.dumps({'app':{'url':self.xgee_app.getWebInstanceUrl()},'eoq':{'url': self.xgee_app.getEoqInstanceUrl()}}))+';'
+        self.write(xgeeapp_conf)
+    
 class EoqConfiguration:
     '''' Default EOQ Configuration '''
     def __init__(self):
@@ -62,10 +73,17 @@ class XGEEApp:
         self.name=str(self.get_conf_parameter('app/name'))
         if self.get_conf_parameter('app/name') is None:
             self.name='Unnamed Application'
+
+        self.appHost=str(self.get_conf_parameter('app/host'))
+        if self.get_conf_parameter('app/host') is None:
+            self.appHost=DEFAULT_HOST       
         self.port=self.get_conf_parameter('app/port')
         self.webInstance=None
 
         # Prepare EOQ configuration
+        self.eoqHost=str(self.get_conf_parameter('eoq/host'))
+        if self.get_conf_parameter('eoq/host') is None:
+            self.eoqHost=DEFAULT_HOST     
         self.eoqPort=self.get_conf_parameter('eoq/port')
         self.eoqInstance=None
         self.eoqThread=None
@@ -114,14 +132,14 @@ class XGEEApp:
         ''' Gets the web instance URL '''
         res=default
         if self.webInstance is not None:
-            res='http://localhost:'+str(self.port)
+            res='http://'+self.appHost+':'+str(self.port)
         return res
 
     def getEoqInstanceUrl(self,default='---'):
         ''' Gets the eoq instance URL '''
         res=default
         if self.eoqInstance is not None:
-            res='ws://localhost:'+str(self.eoqPort)
+            res='ws://'+self.eoqHost+':'+str(self.eoqPort)+'/ws/eoq.do'
         return res
 
     def launch(self): 
@@ -131,6 +149,7 @@ class XGEEApp:
         if self.port is not None:
             application = tornado.web.Application([
             (r"/xgee-core/(.*)", tornado.web.StaticFileHandler, {"path": str(xgeedir)}),
+            (r"/xgee-conf/app.conf.js", XGEEConfigHandler, {"xgee_app":self}),
             (r"/(.*)", tornado.web.StaticFileHandler, {"path": self.path+"/app","default_filename":"index.html"}),
             ])
             self.webInstance=None                           
